@@ -290,6 +290,10 @@ CASE( "test_metkit_expand_13_step" ) {
     step({"0:45"}, {"45m"});
     step({"0:50"}, {"50m"});
     step({"0:55"}, {"55m"});
+    step({"0-24"}, {"0-24"});
+    step({"0-24s"}, {"0s-24s"});
+    step({"0-120s"}, {"0m-2m"});
+    step({"0s-120m"}, {"0-2"});
     step({"1-2"}, {"1-2"});
     step({"30m-1"}, {"30m-60m"});
 
